@@ -23,6 +23,19 @@ from nexusai.error import (
     PermissionError,
     StreamError,
     FileUploadError,
+    NexusAIError,
+)
+
+# Export embedding models for convenience
+from nexusai.models.embedding import (
+    EmbeddingResponse,
+    EmbeddingBatchResponse,
+    EmbeddingModelListResponse,
+    EmbeddingHealthResponse,
+    EmbeddingObject,
+    EmbeddingModel,
+    TokenUsage as EmbeddingTokenUsage,
+    EmbeddingBatchInfo,
 )
 
 __all__ = [
@@ -43,4 +56,14 @@ __all__ = [
     "PermissionError",
     "StreamError",
     "FileUploadError",
+    "NexusAIError",
+    # Embedding models
+    "EmbeddingResponse",
+    "EmbeddingBatchResponse",
+    "EmbeddingModelListResponse",
+    "EmbeddingHealthResponse",
+    "EmbeddingObject",
+    "EmbeddingModel",
+    "EmbeddingTokenUsage",
+    "EmbeddingBatchInfo",
 ]
